#  cpse.spec.in -- an RPM spec file template
#  Copyright (C) 2008  SEIKO EPSON CORPORATION
#
#  This file is part of "Custom Paper Size Editor".
#
#  "Custom Paper Size Editor" is free software.
#  You can redistribute it and/or modify it under the terms of the GNU
#  General Public License as published by the Free Software Foundation;
#  either version 2 of the License or at your option any later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY;  without even the implied warranty of FITNESS
#  FOR A PARTICULAR PURPOSE or MERCHANTABILITY.
#  See the GNU General Public License for more details.
#
#  You should have received a verbatim copy of the GNU General Public
#  License along with this program; if not, write to:
#
#      Free Software Foundation, Inc.
#      59 Temple Place, Suite 330
#      Boston, MA  02111-1307  USA


#  Some handy macro definitions.
#
%define pkg	cpse
%define ver	1.0.1
%define rel	0
%define msg	   %{_tmppath}/%{pkg}-%{ver}-%{rel}.msg
%define datadir    %{_datadir}/%{pkg}
%define pkglibdir  %{_libdir}/%{pkg}
%define pkgdatadir %{datadir}-%{ver}-%{rel}

# ^L	general package information

Name:		%{pkg}
Version:	%{ver}
Release:	%{rel}
Source:		%{pkg}-%{ver}.tar.gz
License:	GPL

Vendor:		SEIKO EPSON CORPORATION
URL:		http://www.epson.com/
Packager:	SEIKO EPSON CORPORATION

BuildRoot:	%{_tmppath}/%{pkg}-%{ver}-%{rel}-root

Group:		Applications/System
Summary:	Custom Paper Size Editor
%description
This software contains a command-line tool and a GUI utility that
makes defining custom paper sizes in supported PPD files a great
deal easier.  Changes can be saved to file or applied directly to
your CUPS registered printer.
At present, PPD files for EPSON serial impact dot matrix (SIDM)
printers and the EPSON TM series receipt printers are supported.

This package provides a command-line version of the program and
includes the documentation.  See %{pkg}-gtk for a GUI version.


%package gtk

Requires:	%{pkg}
Group:		Applications/System
Summary:	Custom Paper Size Editor (GTK+ version)
%description gtk
This software contains a command-line tool and a GUI utility that
makes defining custom paper sizes in supported PPD files a great
deal easier.  Changes can be saved to file or applied directly to
your CUPS registered printer.
At present, PPD files for EPSON serial impact dot matrix (SIDM)
printers and the EPSON TM series receipt printers are supported.

This package provides a GTK+ based GUI version.


# ^L	rpmbuild sections

%prep
%setup -q


%build
%configure --enable-cups-nodeps
make
#%{__ln_s} doc/images


%install
rm -rf ${RPM_BUILD_ROOT}
make install DESTDIR=${RPM_BUILD_ROOT}
#
#  Create a list of message catalogs that should be included in the RPM
#  binary package.  Use %lang(ll) notation so that sysadmins can choose
#  the catalogs they want installed.
#
> %{msg}
cd ${RPM_BUILD_ROOT}/%{_datadir}/locale
for lang in *
do
    test -f ${lang}/LC_MESSAGES/%{pkg}.mo || continue
    ll=`echo ${lang} | sed 's,@.*$,,'`
    echo "%lang(${ll}) %{_datadir}/locale/${lang}/LC_MESSAGES/%{pkg}.mo" >> %{msg}
done


%clean
make clean
rm -rf ${RPM_BUILD_ROOT}
rm -f %{msg}


# ^L	rpm (un)installation scripts, if any
%post gtk
if [ -d %{_datadir}/applications ] ; then
    iconimage=""
    for file in printer1 printer-tray-normal cupsprinter stock_printers ; do
       if [ -f %{_datadir}/pixmaps/${file}.png ] ; then
	  iconimage=${file}
       fi
    done
    cat %{pkgdatadir}/cpse.desktop.in | sed -e s,__PRINTER_ICON_IMAGE__,${iconimage}, > %{_datadir}/applications/cpse.desktop

    sucommand=""
    if [ -d %{_sysconfdir}/pam.d -a -d %{_sysconfdir}/security/console.apps -a -x %{_bindir}/consolehelper-gtk ] ; then
      cp %{pkgdatadir}/consolehelper/cpse-su.desktop  %{_datadir}/applications/cpse-su.desktop     || true
      cp %{pkgdatadir}/consolehelper/cpse-su.pam      %{_sysconfdir}/pam.d/cpse-su                 || true
      cp %{pkgdatadir}/consolehelper/cpse-su.security %{_sysconfdir}/security/console.apps/cpse-su || true
      [ ! -e %{_bindir}/cpse-su ] && ln -s consolehelper-gtk %{_bindir}/cpse-su                    || true
    else
      [ -x %{_bindir}/xdg_menu_su  ] && sucommand=xdg_menu_su                     || true
      [ -x /opt/gnome/bin/gnomesu -o -x %{_bindir}/gnomesu ] && sucommand=gnomesu || true
      [ -x %{_bindir}/kdesu ] && sucommand=kdesu                                  || true
      [ -x %{_bindir}/kdsu  ] && sucommand=kdsu                                   || true
    fi

    if [ -n "${sucommand}" ] ; then
      cat %{pkgdatadir}/cpse-su.desktop.in | sed -e "s,__SUCOMMAND__,${sucommand},;s,__PRINTER_ICON_IMAGE__,${iconimage}," > %{_datadir}/applications/cpse-su.desktop
    fi
fi

%preun gtk
if [ "0" = "$1" ] ; then
    rm -f %{_datadir}/applications/cpse.desktop        || true
    rm -f %{_datadir}/applications/cpse-su.desktop     || true
    rm -f %{_sysconfdir}/pam.d/cpse-su                 || true
    rm -f %{_sysconfdir}/security/console.apps/cpse-su || true
    rm -f %{_bindir}/cpse-su                           || true
fi


# ^L	package contents

#  Note that we generate the %%{msg} file during the %%install phase
#  so that we can use %%lang(xx) notation without the need to resort
#  to a manually maintained list here.
#
%files
%defattr(-,root,root)

%doc	COPYING
#%doc	COPYING.GFDL
%doc	README
#%doc	doc/cpse-style.css
#%doc	doc/cpse-manual.*.html
#%doc --parents	images/*.png

%{_bindir}/%{pkg}

%dir    %{pkglibdir}
%{pkglibdir}/cpse-cli


%files gtk -f %{msg}
%defattr(-,root,root)

%doc	COPYING
%doc	README

%dir    %{pkglibdir}
        %{pkglibdir}/cpse-gtk

%dir    %{datadir}
        %{datadir}/cpse.glade

%dir    %{pkgdatadir}
        %{pkgdatadir}/cpse.desktop.in
	%{pkgdatadir}/cpse-su.desktop.in

%dir    %{pkgdatadir}/consolehelper
	%{pkgdatadir}/consolehelper/cpse-su.pam
	%{pkgdatadir}/consolehelper/cpse-su.security
	%{pkgdatadir}/consolehelper/cpse-su.desktop

# ^L	significant packaging changes

%changelog
* Tue Mar 25 2008  Hidenori Ishii <hidenori.ishii@avasys.jp>
  - add desktop menu files.

* Tue Dec 18 2007  Olaf Meeuwissen <olaf.meeuwissen@avasys.jp>
  - split package in command-line and GUI components

* Wed Nov 14 2007  Olaf Meeuwissen <olaf.meeuwissen@avasys.jp>
  - initial revision
