/*  generix.h -- generally useful C preprocessor magic and tricks
    Copyright (C) 2008  SEIKO EPSON CORPORATION

    This file is part of "Custom Paper Size Editor".

    "Custom Paper Size Editor" is free software.
    You can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation;
    either version 2 of the License or at your option any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY;  without even the implied warranty of FITNESS
    FOR A PARTICULAR PURPOSE or MERCHANTABILITY.
    See the GNU General Public License for more details.

    You should have received a verbatim copy of the GNU General Public
    License along with this program; if not, write to:

        Free Software Foundation, Inc.
        59 Temple Place, Suite 330
        Boston, MA  02111-1307  USA
 */


#ifndef INCLUDED_GENERIX_H
#define INCLUDED_GENERIX_H


/* I18N issues
 */
#include "gettext.h"

#define  _(translatable_string)		gettext (translatable_string)
#define N_(translatable_string)			(translatable_string)


/* Run-time contract validation
 */
#include <stdio.h>
#include <stdlib.h>

#define _assert(type,condition)					\
  if (!(condition))						\
    {								\
      log_err ("failed: %s (%s)", type, #condition);		\
      exit (EXIT_FAILURE);					\
    }
#define require(condition)	_assert ("require", condition)
#define promise(condition)	_assert ("promise", condition)

/* Logging "framework"
 */
#include <errno.h>
#include <stdio.h>
#include <string.h>

#define log_dbg(fmt,va_args...)					\
  fprintf (stderr, "%s:%d:%s: " fmt "\n", __FILE__, __LINE__,	\
	   __FUNCTION__, ##va_args)

#define log_msg	log_dbg
#define log_err	log_msg

#define log_errno(_oops_)	log_msg ("%s", strerror (_oops_))


/* GTK/CLI compatibility
 */

#ifdef CPSE_GTK

#include <gtk/gtk.h>
#include <glade/glade.h>

extern GladeXML *xml;

#else  /* !defined (CPSE_GTK) */

#include <stdlib.h>
#include <string.h>

typedef char		gchar;
typedef unsigned char	guchar;
typedef double		gdouble;
typedef int		gboolean;
typedef int		gint;

#ifndef FALSE
#define FALSE   (0)
#endif
#ifndef TRUE
#define TRUE    (!0)
#endif

#ifdef __unix__
#define G_DIR_SEPARATOR		'/'
#define G_DIR_SEPARATOR_S	"/"
#endif /* defined (__unix__) */

#define g_malloc(n)		malloc (n)
#define g_malloc0(n)		calloc (n, 1)
#define g_realloc(p,n)		realloc (p, n)
#define g_free(p)		if (p) free (p)
#define g_strdup(s)		strdup (s)

#endif /* !defined (CPSE_GTK) */


#endif /* !defined (INCLUDED_GENERIX_H) */
