/*  model.h -- 
    Copyright (C) 2008  SEIKO EPSON CORPORATION

    This file is part of "Custom Paper Size Editor".

    "Custom Paper Size Editor" is free software.
    You can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation;
    either version 2 of the License or at your option any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY;  without even the implied warranty of FITNESS
    FOR A PARTICULAR PURPOSE or MERCHANTABILITY.
    See the GNU General Public License for more details.

    You should have received a verbatim copy of the GNU General Public
    License along with this program; if not, write to:

        Free Software Foundation, Inc.
        59 Temple Place, Suite 330
        Boston, MA  02111-1307  USA
 */


#ifndef INCLUDED_MODEL_H
#define INCLUDED_MODEL_H

#include <cups/cups.h>
#include <cups/ppd.h>

#include "generix.h"


static const gdouble DOTS_PER_INCH = 72.0;
static const gdouble MM_PER_INCH   = 25.4;
static const gdouble CM_PER_INCH   =  2.54;


#define MAX_CUSTOM_PAPERS	20
#define CUSTOM_PAPER_PREFIX	PACKAGE_TARNAME "."
#define CUSTOM_PAPER_FORMAT	CUSTOM_PAPER_PREFIX "%d"

#define CPSE_MIN_WIDTH	1.000 * DOTS_PER_INCH;
#define CPSE_MIN_HEIGHT	1.000 * DOTS_PER_INCH;

static const gdouble CPSE_MIN_RESOLUTION =  10;		/* in dpi */
static const gdouble CPSE_DEF_RESOLUTION = 180;		/* in dpi */
static const gdouble CPSE_MAX_RESOLUTION = 720;		/* in dpi */


typedef struct
{
  gdouble min;
  gdouble max;
  gdouble val;

} CPSEValue;

typedef struct
{
  gchar name[PPD_MAX_NAME];	/* machine readable string */
  gchar text[PPD_MAX_TEXT];	/* human readable string */

  gdouble width;
  gdouble height;
  gdouble resolution;

} CPSEPaper;

typedef struct
{
  const gchar *model;
  const gchar *name;
  const gchar *ppd_file;
	gchar *cups_ppd;

} CPSEPrinter;

typedef enum
  {
    UNIT_CM,
    UNIT_INCH,
    UNIT_MM,
    UNIT_DOTS,
    MAX_UNIT

  } CPSEUnit;

typedef struct
{
  CPSEPrinter printer;

  gboolean has_hw_res;
  gboolean needs_update;

  CPSEUnit units;

  CPSEValue width;
  CPSEValue height;
  CPSEValue resolution;

  gdouble offset_width;
  gdouble offset_height;

  CPSEPaper *custom_paper;
  gint       custom_paper_sz;

  cups_dest_t *dest;
  int	       dest_sz;

} CPSEModel;

enum {
  COL_TEXT,
  COL_WIDTH,
  COL_HEIGHT,
  COL_RESOLUTION,
  COL_NAME,
  MAX_COLUMNS
};



CPSEModel * cpse_model_new (void);
void cpse_model_reset (CPSEModel *m);

gdouble  cpse_model_convert (gdouble value, CPSEUnit from, CPSEUnit to);

size_t   cpse_model_paper_count  (const CPSEModel *m);
gboolean cpse_model_is_duplicate (const CPSEModel *m, const gchar *text);

#ifdef CPSE_GTK
GtkTreeModel * cpse_list_new  (void);
#endif

#endif /* INCLUDED_MODEL_H */
