/*! \file main.c

  \brief rastertoeplq main function

  \author
    Copyright (C) Seiko Epson Corporation 2007.

    Driver for EPSON LQ Series SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>

#include <cups/cups.h>

#include "common.h"
#include "rastertoeplq.h"

/*! \brief main
  \param  argc  number of params
  \param  argv  commandline parameters
  \return       error status
  \retval 0     completed
  \retval other error
 */
int main (int argc, char *argv[])
{
  int            fd = -1;	/* Input File descriptor */
  int            num_options = 0;
  cups_option_t *options = NULL;
  int            status = 0;
  int            i = 0;

  setbuf(stderr, NULL);

  if (argc < 6 || argc > 7)
  {
    fprintf(stderr, "Usage: %s job-id user title copies options [file]\n",
            argv[0]);
    return (1);
  }

 /*
  * Open the page stream...
  */

  if (argc == 7)
  {
    if ((fd = open(argv[6], O_RDONLY)) == -1)
    {
      perror("ERROR: Unable to open raster file - ");
      sleep(1);
      return (1);
    }
  }
  else
    fd = 0;

  for ( i = 0; i < argc; i++ ) {
    dbgprintf("argv[%d]=\"%s\"\n", i, argv[i]);
  }

  num_options = cupsParseOptions( argv[5], 0, &options );

  status = rastertoeplq(fd, num_options, options);

  if (fd != 0)
    close(fd);

  return status;
}
